local mod = RW:Boss("Lady Deathwhisper", "Icecrown Citadell", "Icecrown Citadell", "The Entryway")
local L

-- 3.3?
if not QueryQuestsCompleted then return end

---------------------
-- Variables

-- Lady
local tDominateDur, tDominateCD, mDominate
local tDNDCD, tDNDDur, wDND

-- Adds
local tNextWave
local tEmpowermetCast, iEmpowerment, wEmpowerment
local iVampiric, wVampiric
local wTorpor, mTorpor, tTorporDur
local wShroud
local wMartyr, iMartyr, tMartyrCast

-- General
local tBerserk
local mPhase, wPhase

function mod:OnRegister()
	L = mod:RegisterLocale(self:GetName(), "enUS", true)
	if L then
		L.name = "Lady Deathwhisper"
		
		L.cat_CultAdherent = "Cult Adherent"
		L.cat_CultFanatic = "Cult Fanatic"
		
		L.mana_barrier = GetSpellInfo(70842)
		L.phasewarning = "Phase 2 Starting!"
		L.phasewarning_opt = "Phase Switch"
	end
	L = mod:GetLocale()
	mod.L = L
	
	mod:SetTrigger(36855)
	mod:SetWin()
	
	self:AddCategory(L.name, L_cat_CultAdherent, L_cat_CultFanatic)
	self:AddSpellOption(L.name, 71289, 72109)
	self:AddSpellOption(L.cat_CultAdherent, 70901, 71237, 70768, 72499)
	self:AddSpellOption(L.cat_CultFanatic, 70674)
	
	self:AddBoolOption("ManaShieldHelath", "Show Mana Barrier health", L.name, true)
	
	tDominateDur	= self:DurTargetTimer(20, 71289)
	tDominateCD		= self:CDTimer(40, 71289)
	tDNDCD			= self:CDTimer(20, 72109)
	tDNDDur			= self:DurTimer(10, 72109)
	tBerserk		= self:BerserkTimer(600)
	tEmpowermetCast = self:CastTimer(70901)
	tTorporDur		= self:DurTargetTimer(15, 71237)
	tMartyrCast		= self:CastTimer(72499)
	
	wDND			= self:RunawayWarning(72109)
	wPhase			= self:Warning({L.phasewarning, L.phasewarning}, [[Interface\Icons\Achievement_PVP_A_02.blp]], L.phasewarning_opt)
	wEmpowerment	= self:CastWarning(70901)
	wVampiric		= self:CastWarning(70674)
	wTorpor			= self:Warning(71237)
	wShroud			= self:CastWarning(70768)
	wMartyr			= self:CastWarning(72499)
	
	mDominate		= self:TargetMessage(71289)
	mPhase 			= self:PhaseMessage()
	mTorpor			= self:TargetMessage(71237)
	
	iEmpowerment	= self:Icon("CROSS", 70901, false, nil, "SQUARE")
	iVampiric		= self:Icon("STAR", 70674, false, nil, "CIRCLE")
	iMartyr			= self:Icon("SKULL", 72499, false)
end

----------------------
-- Locals

local manaLeft
local mcTargets = {}
local isCaster = mod.pClass == "MAGE" or mod.pClass == "WARLOCK" or mod.pClass == "DRUID" or mod.pClass == "PRIEST" or mod.pClass == "DEATHKNIGHT"
print(isCaster)


-- Health frames
local function ManaBarrierUpdate()
	local uID = mod:UIDFromCID(36855)
	if uID then
		manaLeft = UnitMana(uID) / UnitManaMax(uID)
	end
	return manaLeft
end

do
	local function ShroudUpdate()
		
	end
end

----------------------
-- Start

function mod:OnEngage(trigger)
	-- Lady
	self:Track("Dominate", 71289)
	self:Track("DND", 72109, 72108)
	self:Track("ManaBarrier", 70842)
	-- Adds
	self:Track("Empowerment", 70901)
	self:Track("Vampiric", 70674)
	self:Track("Torpor", 71237)
	self:Track("Shroud", 70768)
	self:Track("Martyr", 72499)
	
	tBerserk:Start()
	
	if self.db.profile.ManaShieldHelath then
		self:SendMessage("RW_AddHealthFrame", ManaBarrierUpdate, L.mana_barrier)
	end
	
	manaLeft = 1
	wipe(mcTargets)
end

local function showMCTargets()
	mDominate:Show(table.concat(mcTargets, "<, >"))
	wipe(mcTargets)
end

function mod:Dominate(event, args)
	if event == "SPELL_AURA_APPLIED" then
		tDominateDur:Start(args.dName)
		tDominateCD:Start()
		iDominate:Show(args.dName)
		
		mcTargets[#mcTargets + 1] = args.dName
		self:Schedule("MCTargets", 0.2, showMCTargets)
		
	elseif event == "SPELL_AURA_REMOVED" then
		iDominate:Hide(args.dName)
		tDominateDur:Cancel(args.dName)
	end
end

function mod:DND(event, args)
	if event == "SPELL_CAST_SUCCESS" then
		tDNDCD:Start()
		tDNDDur:Start()
		
	elseif event == "SPELL_AURA_APPLIED" then
		if args:IsPlayer() then
			wDND:Show()
		end
	end
end

function mod:ManaBarrier(event, args)
	if event == "SPELL_AURA_REMOVED" then
		mPhase:Show(2)
		wPhase:Show()
		self:SendMessage("RW_RemoveAllHealthFrames")
	end
end

-- Dark Empoverment
do
	local function empScanner(gUID, scanNR)
		local target = mod:UIDFromGUID(gUID)

		iEmpowerment:Show(gUID)
		
		if not target and scanNR < 5 then
			mod:Schedule("EmpScanner", 1, empScanner, gUID or "", scanNR + 1)
		end
	end

	function mod:Empowerment(event, args)
		if event == "SPELL_CAST_START" then
			tEmpowermetCast:Start()
			wEmpowerment:Show()
			
		elseif event == "SPELL_AURA_APPLIED" then
			self:Schedule("EmpScanner", 0.2, empScanner, args.dGUID or "", 1)
		end
	end
end

-- Vampiric Might
do
	local function vampScanner(gUID, scanNR)
		local target = mod:UIDFromGUID(gUID)

		iVampiric:Show(gUID)
		
		if not target and scanNR < 5 then
			mod:Schedule("VampScanner", 1, vampScanner, gUID or "", scanNR + 1)
		end
	end

	function mod:Vampiric(event, args)
		if event == "SPELL_AURA_APPLIED" then
			wVampiric:Show()
			self:Schedule("VampScanner", 0.2, vampScanner, args.dGUID or "", 1)
		end
	end
end

function mod:Torpor(event, args)
	if event == "SPELL_AURA_APPLIED" then
		if args:IsPlayer() then
			wTorpor:Show()
		end
		mTorpor:Show(args.dName)
		tTorporDur:Start(args.dName)
	end
end

function mod:Shroud(event, args)
	if event == "SPELL_CAST_START" then
		if UnitGUID("target") == args.sGUID and self.isCaster then
			wShroud:Show()
		end
	end
end

do
	local function martyrScanner(gUID, scanNR)
		local target = mod:UIDFromGUID(gUID)

		iMartyr:Show(gUID)
		
		if not target and scanNR < 5 then
			mod:Schedule("MartyrScanner", 1, martyrScanner, gUID or "", scanNR + 1)
		end
	end
	
	function mod:Martyr(event, args)
		if event == "SPELL_CAST_START" then
			tMartyrCast:Start()
			wMartyr:Show()
			self:Schedule("MartyrScanner", 0.2, martyrScanner, gUID or "", 1)
		end
	end
end