--[[
Plugin holds default settings (font, colors, textures and more)
]]

----------------------------------
-- Create plugin

local RW = LibStub("AceAddon-3.0"):GetAddon("Raid Watch")
local plugin = RW:Plugin("DefaultSettings")

----------------------------------
-- Locals
local LSM = LibStub("LibSharedMedia-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("RW-2.0-Plugins")

local db

----------------------------------
-- Init

function plugin:OnRegister()
	self.db = RW.db:RegisterNamespace(self:GetName(), RW.defaults)
	db = self.db.profile
end

--[[ function plugin:PluginEnable()
end

function plugin:PluginDisable()
end ]]--

----------------------------------
-- Option creators

function plugin:GetFontSettings()
	local settings = self:MakeDefaults().Font
end

function plugin:GetTextureSettings()
	local settings = self:MakeDefaults().Texture
end

function plugin:MakeDefaults()
	if self.options then return self.options end
	local function get(info)
		return db[info[#info]]
	end
	local function colorGet(info)
		return unpack(db[info[#info]])
	end
	local function set(info, value)
		db[info[#info]] = value
		self:SendMessage("RW_DefaultsChanged", info[#info], value)
	end
	local function colorSet(info, r, g, b, a)
		local color = db[info[#info]]
		color[1], color[2], color[3], color[4] = r, g, b, a
		self:SendMessage("RW_DefaultsChanged", info[#info], db[info[#info]])
	end
	self.options = {
		Font = {
			type = "group",
			name = L.FONT_MAIN,
			guiInline = true,
			get = get,
			set = set,
			args = {
				Font = {
					type = "select",
					name = L.FONT,
					dialogControl = "LSM30_Font",
					values = AceGUIWidgetLSMlists.font,
					order = 1,
				},
				FontSize = {
					type = "range",
					name = L.FONT_SIZE,
					step = 1,
					min = 5,
					max = 40,
					order = 2,
				},
				FontColor = {
					type = "color",
					name = L.FONT_COLOR,
					hasAlpha = true,
					get = colorGet,
					set = colorSet,
					order = 3,
				},
				FontOutline = {
					type = "select",
					name = L.FONT_OUTLINE,
					desc = L.FONT_OUTLINE_DESC,
					values = {OUTLINE = "Outline", THICKOUTLINE = "Thick Outline", NONE = "None"}, 
					order = 4,
				},
			}
		},
		Texture = {
			type = "group",
			name = L.TEXTURE_MAIN,
			guiInline = true,
			get = get,
			set = set,
			args = {
				Border = {
					type = "select",
					name = L.BORDER,
					dialogControl = "LSM30_Border",
					values = AceGUIWidgetLSMlists.border,
					order = 1,
				},
				BorderColor = {
					type = "color",
					name = L.BORDER_COLOR,
					hasAlpha = true,
					set = colorSet,
					get = colorGet,
					order = 2,
				},
				BorderSize = {
					type = "range",
					name = L.BORDER_SIZE,
					step = 1,
					min = 0,
					max = 40,
					width = "full",
					order = 3,
				},
				BarTexture = {
					type = "select",
					name = L.BAR_TEXTURE,
					dialogControl = "LSM30_Statusbar",
					values = AceGUIWidgetLSMlists.statusbar,
					order = 4,
				},
				BarColor = {
					type = "color",
					name = L.BAR_COLOR,
					get = colorGet,
					set = colorSet,
					order = 5,
				}
			}
		}
	}
	return self.options
end

function plugin:GetOptions()
	self.category = "Misc"
	local default = {
		name = "Default settings",
		type = "group",
		args = self:MakeDefaults(),
	}
	return default
end
